import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:marketing_plugin/plugin_codelab.dart';

class NativeExample extends StatefulWidget {
  final dynamic colors;
  final String? ids;
  final bool isCustomeads;

  const NativeExample(
      {Key? key, this.colors, this.ids, this.isCustomeads = false})
      : super(key: key);

  @override
  State<NativeExample> createState() => _NativeExampleState();
}

class _NativeExampleState extends State<NativeExample> {
  NativeAd? _nativeAd;
  bool _nativeAdIsLoaded = false;

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    loadAd();
  }

  // TODO: replace this test ad unit with your own ad unit.

  /// Loads a native ad.
  void loadAd() {
    _nativeAd = NativeAd(
        adUnitId: widget.ids ?? '',
        listener: NativeAdListener(
          onAdLoaded: (ad) {
            debugPrint('$NativeAd loaded.');
            setState(() {
              _nativeAdIsLoaded = true;
            });
          },
          onAdFailedToLoad: (ad, error) {
            // Dispose the ad here to free resources.
            debugPrint('$NativeAd failed to load: $error');
            ad.dispose();
          },
        ),
        request: const AdManagerAdRequest(),
        // Styling
        nativeTemplateStyle: widget.isCustomeads
            ? NativeTemplateStyle(
          // Required: Choose a template.
            templateType: TemplateType.medium,
            // Optional: Customize the ad's style.
            mainBackgroundColor:
            HexColor.fromHexColor(widget.colors['background']),
            cornerRadius: 10.0,
            callToActionTextStyle: NativeTemplateTextStyle(
                backgroundColor: HexColor.fromHexColor(widget.colors['button']),
                textColor: HexColor.fromHexColor(widget.colors['text']),
                style: NativeTemplateFontStyle.monospace,
                size: 16.0),
            primaryTextStyle: NativeTemplateTextStyle(
                textColor: HexColor.fromHexColor(widget.colors['title']),
                style: NativeTemplateFontStyle.italic,
                size: 16.0),
            secondaryTextStyle: NativeTemplateTextStyle(
                textColor: HexColor.fromHexColor(widget.colors['title']),
                style: NativeTemplateFontStyle.bold,
                size: 16.0),
            tertiaryTextStyle: NativeTemplateTextStyle(
                style: NativeTemplateFontStyle.normal, size: 16.0))
            : NativeTemplateStyle(
          // Required: Choose a template.
          templateType: TemplateType.medium,))
      ..load();
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    if (_nativeAdIsLoaded) {
      return ConstrainedBox(
        constraints: const BoxConstraints(
          minWidth: 320, // minimum recommended width
          minHeight: 320, // minimum recommended height
          maxWidth: 400,
          maxHeight: 400,
        ),
        child: AdWidget(ad: _nativeAd!),
      );
    }
    return Container();
  }

  @override
  void dispose() {
    super.dispose();
  }
}
